==> docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0/luna-sdk_alma_rel_v.5.32.0/doc/fsdk/html/search/enumvalues_3.js <==
var searchData=
[
  ['dct_5fcenter',['DCT_CENTER',['../group___detector_group.html#gga7d021e05a5d867ffe947ffb40aa0923da763dab49108298d2d502a9749e2628e9',1,'fsdk']]],
  ['dct_5fcenter_5fand_5fconfidence',['DCT_CENTER_AND_CONFIDENCE',['../group___detector_group.html#gga7d021e05a5d867ffe947ffb40aa0923da113aa401fd3bbad089894a3cf8fd06b6',1,'fsdk']]],
  ['dct_5fconfidence',['DCT_CONFIDENCE',['../group___detector_group.html#gga7d021e05a5d867ffe947ffb40aa0923da8767054041a6b3288648b7a403ca7b17',1,'fsdk']]],
  ['dct_5fsize',['DCT_SIZE',['../group___detector_group.html#gga7d021e05a5d867ffe947ffb40aa0923dab87d650f70c0d623b1419a50c24ce590',1,'fsdk']]],
  ['default',['Default',['../structfsdk_1_1_i_serializable_object.html#ac02b734576139d792a928b0a9ade7d79a6e4800456cd37d67c1cdcfecaac8afab',1,'fsdk::ISerializableObject']]],
  ['dis_5finvalid',['DIS_INVALID',['../namespacefsdk.html#a2210630f9c7bff2cc7d785cc8e2b8ee1a59022e450a16f091e78179a9ec8a49a2',1,'fsdk']]],
  ['dis_5funknown',['DIS_UNKNOWN',['../namespacefsdk.html#a2210630f9c7bff2cc7d785cc8e2b8ee1a8cc154b216d939d047de68831567f504',1,'fsdk']]],
  ['dis_5fvalid',['DIS_VALID',['../namespacefsdk.html#a2210630f9c7bff2cc7d785cc8e2b8ee1a685715eb7fdce208bfa6bae51eaa8c5f',1,'fsdk']]],
  ['dt_5fall',['DT_ALL',['../group___detector_group.html#gga29cb345293d30553e7af41260cede7ada1be6a902d3612661d3200257c69323fa',1,'fsdk']]],
  ['dt_5fbbox',['DT_BBOX',['../group___detector_group.html#gga29cb345293d30553e7af41260cede7adafc1e9f167d5d1be9899f6732bc6f2110',1,'fsdk']]],
  ['dt_5fface',['DT_FACE',['../group___descriptor_processing_group.html#gga1cd2e0e27848b58fe8d39becd00d6186adfd064a1bc06eda4ce5ad8cbb32ceb05',1,'fsdk']]],
  ['dt_5fhuman',['DT_HUMAN',['../group___descriptor_processing_group.html#gga1cd2e0e27848b58fe8d39becd00d6186a55aa0ee5f96f43689faa8dc86966340e',1,'fsdk']]],
  ['dt_5flandmarks5',['DT_LANDMARKS5',['../group___detector_group.html#gga29cb345293d30553e7af41260cede7ada3a1cef8a2d392799c66fe948b3cee9f4',1,'fsdk']]],
  ['dt_5flandmarks68',['DT_LANDMARKS68',['../group___detector_group.html#gga29cb345293d30553e7af41260cede7ada508e9b2f679d5758e9bf979610dbb1c5',1,'fsdk']]],
  ['dv_5fmin_5fface_5fdescriptor_5fversion',['DV_MIN_FACE_DESCRIPTOR_VERSION',['../group___descriptor_processing_group.html#ggaa796beff9fb761301be4e46b1a2412aba1dfe29faa054d00d13d992fdfcffaef4',1,'fsdk']]],
  ['dv_5fmin_5fhuman_5fdescriptor_5fversion',['DV_MIN_HUMAN_DESCRIPTOR_VERSION',['../group___descriptor_processing_group.html#ggaa796beff9fb761301be4e46b1a2412aba663094a3a39d591eca695b631243f71a',1,'fsdk']]]
];

==> docs_sdk_archive_luna-sdk_alma_rel_v.5.34.0.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.34.0/luna-sdk_alma_rel_v.5.34.0/doc/fsdk/html/search/enumvalues_3.js <==
var searchData=
[
  ['dark',['Dark',['../structfsdk_1_1_light_colored_clothes_estimation.html#ac9e69ae4fab2f62191098e7593862b27aa18366b217ebf811ad1886e4f4f865b2',1,'fsdk::LightColoredClothesEstimation']]],
  ['dct_5fcenter',['DCT_CENTER',['../group___detector_group.html#gga7d021e05a5d867ffe947ffb40aa0923da763dab49108298d2d502a9749e2628e9',1,'fsdk']]],
  ['dct_5fcenter_5fand_5fconfidence',['DCT_CENTER_AND_CONFIDENCE',['../group___detector_group.html#gga7d021e05a5d867ffe947ffb40aa0923da113aa401fd3bbad089894a3cf8fd06b6',1,'fsdk']]],
  ['dct_5fconfidence',['DCT_CONFIDENCE',['../group___detector_group.html#gga7d021e05a5d867ffe947ffb40aa0923da8767054041a6b3288648b7a403ca7b17',1,'fsdk']]],
  ['dct_5fsize',['DCT_SIZE',['../group___detector_group.html#gga7d021e05a5d867ffe947ffb40aa0923dab87d650f70c0d623b1419a50c24ce590',1,'fsdk']]],
  ['default',['Default',['../structfsdk_1_1_i_serializable_object.html#ac02b734576139d792a928b0a9ade7d79a6e4800456cd37d67c1cdcfecaac8afab',1,'fsdk::ISerializableObject']]],
  ['dis_5finvalid',['DIS_INVALID',['../namespacefsdk.html#a2210630f9c7bff2cc7d785cc8e2b8ee1a59022e450a16f091e78179a9ec8a49a2',1,'fsdk']]],
  ['dis_5funknown',['DIS_UNKNOWN',['../namespacefsdk.html#a2210630f9c7bff2cc7d785cc8e2b8ee1a8cc154b216d939d047de68831567f504',1,'fsdk']]],
  ['dis_5fvalid',['DIS_VALID',['../namespacefsdk.html#a2210630f9c7bff2cc7d785cc8e2b8ee1a685715eb7fdce208bfa6bae51eaa8c5f',1,'fsdk']]],
  ['drawn',['Drawn',['../structfsdk_1_1_photorealistic_face_estimation.html#a02d580080a36d0718bb4b1bb78178efbac4816e491f1e2cf4b8c26d844861d8fe',1,'fsdk::PhotorealisticFaceEstimation']]],
  ['dt_5fall',['DT_ALL',['../group___detector_group.html#gga29cb345293d30553e7af41260cede7ada1be6a902d3612661d3200257c69323fa',1,'fsdk']]],
  ['dt_5fbbox',['DT_BBOX',['../group___detector_group.html#gga29cb345293d30553e7af41260cede7adafc1e9f167d5d1be9899f6732bc6f2110',1,'fsdk']]],
  ['dt_5fface',['DT_FACE',['../group___descriptor_processing_group.html#gga1cd2e0e27848b58fe8d39becd00d6186adfd064a1bc06eda4ce5ad8cbb32ceb05',1,'fsdk']]],
  ['dt_5fhuman',['DT_HUMAN',['../group___descriptor_processing_group.html#gga1cd2e0e27848b58fe8d39becd00d6186a55aa0ee5f96f43689faa8dc86966340e',1,'fsdk']]],
  ['dt_5flandmarks5',['DT_LANDMARKS5',['../group___detector_group.html#gga29cb345293d30553e7af41260cede7ada3a1cef8a2d392799c66fe948b3cee9f4',1,'fsdk']]],
  ['dt_5flandmarks68',['DT_LANDMARKS68',['../group___detector_group.html#gga29cb345293d30553e7af41260cede7ada508e9b2f679d5758e9bf979610dbb1c5',1,'fsdk']]],
  ['dv_5fmin_5fface_5fdescriptor_5fversion',['DV_MIN_FACE_DESCRIPTOR_VERSION',['../group___descriptor_processing_group.html#ggaa796beff9fb761301be4e46b1a2412aba1dfe29faa054d00d13d992fdfcffaef4',1,'fsdk']]],
  ['dv_5fmin_5fhuman_5fdescriptor_5fversion',['DV_MIN_HUMAN_DESCRIPTOR_VERSION',['../group___descriptor_processing_group.html#ggaa796beff9fb761301be4e46b1a2412aba663094a3a39d591eca695b631243f71a',1,'fsdk']]]
];
